@@ -9,6 +9,7 @@ import fire  # type: ignore
 from tqdm import tqdm  # type: ignore
 from .persistor import Persistor
 from .daemon import start
+from .graph import graph
 
 
 class HyperTag:
@@ -27,6 +28,7 @@ class HyperTag:
         """ Add file system tag representation using symlinks """
         if parent_tag_id is None:
             print("Updating HyperTagFS...")
+            graph()
             tag_ids_names = self.db.get_root_tag_ids_names()
         else:
             tag_ids_names = self.db.get_tag_id_children_ids_names(parent_tag_id)
@@ -158,7 +160,7 @@ class HyperTag:
             # print("Tagged", file_name, "with", tags)
         if commit:
             self.db.conn.commit()
-        # Remount (everything is mounted TODO: make it lazy)
+        # Remount (everything is mounted)
         if remount:
             self.mount(self.root_dir)
 
@@ -184,7 +186,7 @@ class HyperTag:
             # print("Tagged", file_name, "with", tags)
         if commit:
             self.db.conn.commit()
-        # Remount (everything is mounted TODO: make it lazy)
+        # Remount (everything is mounted)
         if remount:
             self.mount(self.root_dir)
 
@@ -218,7 +220,7 @@ class HyperTag:
             # print("MetaTagged", tag, "with", parent_tags)
         if commit:
             self.db.conn.commit()
-        # Remount (everything is mounted TODO: make it lazy)
+        # Remount (everything is mounted)
         if remount:
             self.mount(self.root_dir)
         # Remove tag/s dir in root level
@@ -229,19 +231,19 @@ class HyperTag:
                 except:  # nosec
                     pass  # Ignore if non existing
 
-    def rmdir(self, dir_name):
-        # Delete directory recursively
-        directory = self.root_dir
+    def rmdir(self, directory, del_dir_name):
+        # Delete dirs named del_dir_name in directory recursively
         for item in directory.iterdir():
-            if item.name == dir_name and item.is_dir():
+            if item.name == del_dir_name and item.is_dir():
                 rmtree(item)
-                self.rmdir(item)
+            if item.is_dir():
+                self.rmdir(item, del_dir_name)
 
     def merge(self, tag_a, _into, tag_b):
         """ Merges all associations (files & tags) of tag_a into tag_b """
         print("Merging tag", tag_a, "into", tag_b)
         self.db.merge_tags(tag_a, tag_b)
-        self.rmdir(tag_a)
+        self.rmdir(self.root_dir, tag_a)
         self.mount(self.root_dir)
 
 
@@ -267,6 +269,7 @@ def main():
         "query": ht.query,
         "set_hypertagfs_dir": ht.set_hypertagfs_dir,
         "daemon": daemon,
+        "graph": graph,
     }
     fire.Fire(fire_cli)
 
